# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List  # pylint: disable=unused-import
from ..protobufs import main_pb2
from .servo_tuning_param import ServoTuningParam


class ParamsetInfo:
    """
    The raw parameters currently saved to a given paramset.
    """

    @property
    def type(self) -> str:
        """
        The tuning algorithm used for this axis.
        """

        return self._type

    @type.setter
    def type(self, value: str) -> None:
        self._type = value

    @property
    def params(self) -> List[ServoTuningParam]:
        """
        The raw tuning parameters of this device.
        """

        return self._params

    @params.setter
    def params(self, value: List[ServoTuningParam]) -> None:
        self._params = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.ParamsetInfo
    ) -> 'ParamsetInfo':
        instance = ParamsetInfo.__new__(
            ParamsetInfo
        )  # type: ParamsetInfo
        instance.type = pb_data.type
        instance.params = [ServoTuningParam.from_protobuf(item) for item in pb_data.params]
        return instance



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\xdd\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\x12\x13\n\x0bis_modified\x18\x05 \x01(\x08\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\xcb\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x13\n\x0bis_modified\x18\x06 \x01(\x08\x12\x15\n\ris_integrated\x18\x07 \x01(\x08\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"\x8a\x01\n\x0c\x44\x65viceIOInfo\x12\x1d\n\x15number_analog_outputs\x18\x02 \x01(\x05\x12\x1c\n\x14number_analog_inputs\x18\x03 \x01(\x05\x12\x1e\n\x16number_digital_outputs\x18\x04 \x01(\x05\x12\x1d\n\x15number_digital_inputs\x18\x05 \x01(\x05\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\">\n\x14StreamAxisDefinition\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x11\n\taxis_type\x18\x02 \x01(\x05\"<\n\x1aInvalidPacketExceptionData\x12\x0e\n\x06packet\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\">\n\"DeviceAddressConflictExceptionData\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"D\n MovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"J\n&StreamMovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"?\n\x1bMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"E\n!StreamMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"B\n\x1cStreamExecutionExceptionData\x12\x12\n\nerror_flag\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"0\n\x1cInvalidResponseExceptionData\x12\x10\n\x08response\x18\x01 \x01(\t\"m\n\x1a\x43ommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\t\x12\x12\n\nreply_flag\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x07 \x01(\t\"9\n BinaryCommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\x05\"o\n\x1fSetPeripheralStateExceptionData\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x10\n\x08settings\x18\x02 \x03(\t\x12\x14\n\x0cservo_tuning\x18\x03 \x01(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\"\xe1\x01\n\x1bSetDeviceStateExceptionData\x12L\n\x0bperipherals\x18\x02 \x03(\x0b\x32\x37.zaber.motion.protobufs.SetPeripheralStateExceptionData\x12\x10\n\x08settings\x18\x03 \x03(\t\x12\x16\n\x0estream_buffers\x18\x04 \x03(\t\x12\x10\n\x08triggers\x18\x05 \x03(\t\x12\x11\n\tip_config\x18\x06 \x01(\t\x12\x14\n\x0cservo_tuning\x18\x07 \x01(\t\x12\x0f\n\x07storage\x18\x08 \x03(\t\"V\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\x12\x1e\n\x16return_error_with_data\x18\x03 \x01(\x08\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"%\n\x10TestResponseLong\x12\x11\n\tdata_pong\x18\x01 \x03(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"-\n\x1cGetMessageRouterPipeResponse\x12\r\n\x05value\x18\x01 \x01(\t\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"\xa7\x02\n\x14OpenInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\x05\x12 \n\x18reject_routed_connection\x18\x07 \x01(\x08\x12\x10\n\x08\x63loud_id\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_name\x18\t \x01(\t\x12\r\n\x05realm\x18\n \x01(\t\x12\r\n\x05token\x18\x0b \x01(\t\x12\x0b\n\x03\x61pi\x18\x0c \x01(\t\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x43loseInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x45mptyInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\",\n\x1bGetInterfaceTimeoutResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"C\n\x1aSetInterfaceTimeoutRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"4\n#GetInterfaceChecksumEnabledResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"N\n\"SetInterfaceChecksumEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"E\n\x0fToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\"\n\x10ToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"\x83\x01\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"0\n\x16\x44\x65viceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xf6\x01\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"=\n\x15\x44\x65viceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"C\n\x12\x44\x65viceOnAllRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"/\n\x13\x44\x65viceOnAllResponse\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"@\n\x18\x44\x65viceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"U\n\x19\x44\x65viceGetIdentityResponse\x12\x38\n\x08identity\x18\x01 \x01(\x0b\x32&.zaber.motion.protobufs.DeviceIdentity\"D\n\x1c\x44\x65viceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x1d\x44\x65viceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"R\n\x1c\x44\x65viceGetAxisIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"W\n\x1d\x44\x65viceGetAxisIdentityResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.AxisIdentity\"I\n\x13\x44\x65viceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\'\n\x14\x44\x65viceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"Z\n\x1c\x44\x65viceGetAllDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\"/\n\x1d\x44\x65viceGetAllDigitalIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x08\"Y\n\x1b\x44\x65viceGetAllAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\".\n\x1c\x44\x65viceGetAllAnalogIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"o\n\x19\x44\x65viceGetDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"+\n\x1a\x44\x65viceGetDigitalIOResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"n\n\x18\x44\x65viceGetAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"*\n\x19\x44\x65viceGetAnalogIOResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"Y\n!DeviceSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x08\"X\n DeviceSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x01\"l\n\x1d\x44\x65viceSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x08\"k\n\x1c\x44\x65viceSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\"F\n\x1e\x44\x65viceGetIOChannelsInfoRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\")\n\x18\x44\x65viceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\",\n\x1b\x44\x65viceGetSettingStrResponse\x12\r\n\x05value\x18\x01 \x01(\t\"\x94\x01\n\x1b\x44\x65viceConvertSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\x12\x13\n\x0b\x66rom_native\x18\x07 \x01(\x08\"-\n\x1c\x44\x65viceConvertSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"p\n\x1a\x44\x65viceSetSettingStrRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\")\n\x16PrepareCommandResponse\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"G\n\x11\x44\x65viceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"+\n\x16\x44\x65viceIsParkedResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08\"f\n\x15LockstepEnableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"r\n\x16LockstepDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"\x87\x02\n\x13LockstepMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12\x42\n\x04type\x18\x05 \x01(\x0e\x32\x34.zaber.motion.protobufs.LockstepMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x08 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"}\n\x1cLockstepWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"X\n\x15LockstepIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\")\n\x16LockstepIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"Y\n\x16LockstepGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"N\n\x0cLockstepAxes\x12\x0e\n\x06\x61xis_1\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x61xis_3\x18\x03 \x01(\x05\x12\x0e\n\x06\x61xis_4\x18\x04 \x01(\x05\"M\n\x17LockstepGetAxesResponse\x12\x32\n\x04\x61xes\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.LockstepAxes\"`\n\x1dLockstepGetAxisNumbersRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\".\n\x1eLockstepGetAxisNumbersResponse\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x05\"i\n\x18LockstepGetTwistsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"+\n\x19LockstepGetTwistsResponse\x12\x0e\n\x06twists\x18\x01 \x03(\x01\"j\n\x19LockstepGetOffsetsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"-\n\x1aLockstepGetOffsetsResponse\x12\x0f\n\x07offsets\x18\x01 \x03(\x01\"[\n\x18LockstepIsEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"/\n\x19LockstepIsEnabledResponse\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\"Z\n\x17LockstepToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"*\n\x18LockstepToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"d\n\x1dOscilloscopeAddChannelRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\"H\n OscilloscopeClearChannelsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"S\n\x1cOscilloscopeStartStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x08\"?\n\x17OscilloscopeReadRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\",\n\x18OscilloscopeReadResponse\x12\x10\n\x08\x64\x61ta_ids\x18\x01 \x03(\x05\"S\n\x1aOscilloscopeDataIdentifier\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\"E\n\x1dOscilloscopeCaptureProperties\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\x13\n\x0b\x61xis_number\x18\x02 \x01(\x05\"r\n%OscilloscopeDataGetPropertiesResponse\x12I\n\nproperties\x18\x01 \x01(\x0b\x32\x35.zaber.motion.protobufs.OscilloscopeCaptureProperties\"m\n&OscilloscopeDataGetSavedSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"8\n\'OscilloscopeDataGetSavedSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"z\n$OscilloscopeDataGetSampleTimeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\"h\n!OscilloscopeDataGetSamplesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x64\x61ta_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"2\n\"OscilloscopeDataGetSamplesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"_\n\x16StreamSetupLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"\x96\x01\n\x1fStreamSetupLiveCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12:\n\x04\x61xes\x18\x04 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"w\n\x17StreamSetupStoreRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x05 \x03(\x05\"\xae\x01\n StreamSetupStoreCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12:\n\x04\x61xes\x18\x05 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\x8a\x01\n$StreamSetupStoreArbitraryAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x12\n\naxes_count\x18\x05 \x01(\x05\"c\n\x11StreamCallRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\"\xf8\x01\n\x11StreamLineRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12<\n\x04type\x18\x04 \x01(\x0e\x32..zaber.motion.protobufs.StreamLineRequest.Type\x12\x35\n\x08\x65ndpoint\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x06 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xb1\x03\n\x10StreamArcRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12;\n\x04type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.StreamArcRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_x\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_y\x18\t \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\n \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xcf\x02\n\x13StreamCircleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12>\n\x04type\x18\x04 \x01(\x0e\x32\x30.zaber.motion.protobufs.StreamCircleRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x08 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x7f\n\x1dStreamWaitDigitalInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"\x91\x01\n\x1cStreamWaitAnalogInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\x11\n\tcondition\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\"\x7f\n\x1dStreamSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"~\n\x1cStreamSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x01\"s\n StreamToggleDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"l\n!StreamSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x08\"k\n StreamSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x01\"h\n\x11StreamWaitRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n\x1aStreamWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"L\n\x11StreamCorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamUncorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"\'\n\x14StreamIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"O\n\x14StreamGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"S\n\x15StreamGetAxesResponse\x12:\n\x04\x61xes\x18\x01 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"O\n\x14StreamGetModeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"%\n\x15StreamGetModeResponse\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"a\n\x18StreamGetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\".\n\x19StreamGetMaxSpeedResponse\x12\x11\n\tmax_speed\x18\x01 \x01(\x01\"t\n\x18StreamSetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x11\n\tmax_speed\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"r\n)StreamGetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"Q\n*StreamGetMaxTangentialAccelerationResponse\x12#\n\x1bmax_tangential_acceleration\x18\x01 \x01(\x01\"\x97\x01\n)StreamSetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12#\n\x1bmax_tangential_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n*StreamGetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"S\n+StreamGetMaxCentripetalAccelerationResponse\x12$\n\x1cmax_centripetal_acceleration\x18\x01 \x01(\x01\"\x99\x01\n*StreamSetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12$\n\x1cmax_centripetal_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"P\n\x15StreamToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"(\n\x16StreamToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"O\n\x14StreamDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"X\n\x1dStreamBufferGetContentRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"6\n\x1eStreamBufferGetContentResponse\x12\x14\n\x0c\x62uffer_lines\x18\x01 \x03(\t\"S\n\x18StreamBufferEraseRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"g\n\x1bStreamGenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\"j\n StreamGenericCommandBatchRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\r\n\x05\x62\x61tch\x18\x04 \x03(\t\"c\n\x14\x42inaryReplyOnlyEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\xbb\x01\n\x1aOpenBinaryInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x17\n\x0fuse_message_ids\x18\x06 \x01(\x08\"i\n\x1aUnknownBinaryResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\x82\x01\n\x14GenericBinaryRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x01\"F\n\rBinaryMessage\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x05\"R\n\x17\x42inaryMessageCollection\x12\x37\n\x08messages\x18\x02 \x03(\x0b\x32%.zaber.motion.protobufs.BinaryMessage\"3\n\x1b\x42inaryDeviceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"6\n\x1c\x42inaryDeviceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"C\n\x1b\x42inaryDeviceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xd9\x02\n\x14\x42inaryDeviceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x15\n\ris_peripheral\x18\x06 \x01(\x08\x12\x15\n\rperipheral_id\x18\x07 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x08 \x01(\t\x12L\n\x0b\x64\x65vice_type\x18\t \x01(\x0e\x32\x37.zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType\"1\n\nDeviceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"F\n\x1e\x42inaryDeviceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"a\n\x1f\x42inaryDeviceGetIdentityResponse\x12>\n\x08identity\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.BinaryDeviceIdentity\"J\n\"BinaryDeviceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"<\n#BinaryDeviceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"\x99\x01\n\x1d\x42inaryGenericWithUnitsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x01\x12\x11\n\tfrom_unit\x18\x05 \x01(\t\x12\x0f\n\x07to_unit\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x01\".\n\x1e\x42inaryGenericWithUnitsResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"^\n\x17\x42inaryDeviceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\",\n\x1c\x42inaryDeviceMovementResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"\xda\x01\n\x17\x42inaryDeviceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x46\n\x04type\x18\x04 \x01(\x0e\x32\x38.zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"^\n\x17\x42inaryDeviceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"H\n BinaryDeviceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"A\n\x19\x42inaryDeviceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x1a\x42inaryDeviceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"K\n\x19\x42inaryDeviceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"-\n\x1a\x42inaryDeviceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"d\n\x1d\x42inaryDeviceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"/\n\x1e\x42inaryDeviceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"s\n\x1d\x42inaryDeviceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"?\n\x17\x42inaryDeviceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x18\x42inaryDeviceParkResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08\"2\n\x1a\x43ustomInterfaceReadRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\".\n\x1b\x43ustomInterfaceReadResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"D\n\x1b\x43ustomInterfaceWriteRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x1b\x43ustomInterfaceOpenResponse\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"J\n\x1b\x43ustomInterfaceCloseRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"E\n\x0fGetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"!\n\x10GetStateResponse\x12\r\n\x05state\x18\x01 \x01(\t\"l\n\x12\x43\x61nSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"=\n\x17\x43\x61nSetStateAxisResponse\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"v\n\x19\x43\x61nSetStateDeviceResponse\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12J\n\x11peripheral_errors\x18\x03 \x03(\x0b\x32/.zaber.motion.protobufs.CanSetStateAxisResponse\"i\n\x0fSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"Z\n\x12ServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\"/\n\x10ServoTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"V\n\x0cParamsetInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x38\n\x06params\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"\x9e\x01\n\x15SetServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12?\n\rtuning_params\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"H\n\x12GetStartupParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"#\n\x0fStartupParamset\x12\x10\n\x08paramset\x18\x01 \x01(\x05\"n\n\x0cLoadParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x13\n\x0bto_paramset\x18\x04 \x01(\x05\x12\x15\n\rfrom_paramset\x18\x05 \x01(\x05\"\x8d\x01\n\x18SetServoTuningPIDRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\t\n\x01p\x18\x05 \x01(\x01\x12\t\n\x01i\x18\x06 \x01(\x01\x12\t\n\x01\x64\x18\x07 \x01(\x01\x12\n\n\x02\x66\x63\x18\x08 \x01(\x01\"W\n\tPidTuning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\t\n\x01p\x18\x03 \x01(\x01\x12\t\n\x01i\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01\x12\n\n\x02\x66\x63\x18\x06 \x01(\x01\"U\n\x1fGetSimpleTuningParamListRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\xc2\x01\n\x0fSetSimpleTuning\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\x15\n\rcarriage_mass\x18\x05 \x01(\x01\x12\x11\n\tload_mass\x18\x06 \x01(\x01\x12?\n\rtuning_params\x18\x07 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"Z\n\x11SimpleTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_label\x18\x02 \x01(\t\x12\x11\n\tmax_label\x18\x03 \x01(\t\x12\x11\n\tdata_type\x18\x04 \x01(\t\"R\n\x15SimpleTuningParamList\x12\x39\n\x06params\x18\x01 \x03(\x0b\x32).zaber.motion.protobufs.SimpleTuningParam\"\x95\x01\n\x17TranslatorCreateRequest\x12@\n\ndefinition\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.TranslatorDefinition\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"1\n\x18TranslatorCreateResponse\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"O\n\x18TranslatorAxisDefinition\x12\x15\n\rperipheral_id\x18\x01 \x01(\x05\x12\x1c\n\x14microstep_resolution\x18\x02 \x01(\x05\"\xa1\x01\n\x14TranslatorDefinition\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12>\n\x04\x61xes\x18\x02 \x03(\x0b\x32\x30.zaber.motion.protobufs.TranslatorAxisDefinition\x12\x36\n\tmax_speed\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"\xac\x01\n\x10TranslatorConfig\x12\x44\n\raxis_mappings\x18\x01 \x03(\x0b\x32-.zaber.motion.protobufs.TranslatorAxisMapping\x12R\n\x14\x61xis_transformations\x18\x02 \x03(\x0b\x32\x34.zaber.motion.protobufs.TranslatorAxisTransformation\"@\n\x15TranslatorAxisMapping\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x12\n\naxis_index\x18\x02 \x01(\x05\"~\n\x1cTranslatorAxisTransformation\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x0f\n\x07scaling\x18\x02 \x01(\x01\x12\x38\n\x0btranslation\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"B\n\x1aTranslatorTranslateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\r\n\x05\x62lock\x18\x02 \x01(\t\"I\n\x10TranslateMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nfrom_block\x18\x02 \x01(\x05\x12\x10\n\x08to_block\x18\x03 \x01(\x05\"k\n\x1bTranslatorTranslateResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\x12:\n\x08warnings\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.TranslateMessage\"@\n\x18GCodeSyntaxExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"C\n\x1bGCodeExecutionExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"L\n\x1aTranslatorFlushLiveRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"+\n\x17TranslatorFlushResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\"\x90\x01\n\x1bTranslatorCreateLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"/\n\x16TranslatorEmptyRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"^\n TranslatorSetTraverseRateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x15\n\rtraverse_rate\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n TranslatorSetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"U\n TranslatorGetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"2\n!TranslatorGetAxisPositionResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"n\n\x1eTranslatorGetAxisOffsetRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x19\n\x11\x63oordinate_system\x18\x02 \x01(\t\x12\x0c\n\x04\x61xis\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\"=\n,TranslatorGetCurrentCoordinateSystemResponse\x12\r\n\x05value\x18\x01 \x01(\t\"R\n$TranslatorSetFeedRateOverrideRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63oefficient\x18\x02 \x01(\x01*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\xcb\x07\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1b\n\x17\x44\x45VICE_ADDRESS_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\r\n\tIO_FAILED\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\r\n\tOS_FAILED\x10\x14\x12\x12\n\x0eINTERNAL_ERROR\x10\x16\x12\x19\n\x15\x42INARY_COMMAND_FAILED\x10\x18\x12\x15\n\x11\x43OMMAND_PREEMPTED\x10\x19\x12\x18\n\x14LOCKSTEP_NOT_ENABLED\x10\x1a\x12\x14\n\x10LOCKSTEP_ENABLED\x10\x1b\x12\x1b\n\x17IO_CHANNEL_OUT_OF_RANGE\x10\x1c\x12\x15\n\x11SETTING_NOT_FOUND\x10\x1d\x12\x0f\n\x0bSTREAM_MODE\x10\x1e\x12\x14\n\x10STREAM_EXECUTION\x10\x1f\x12\x1a\n\x16STREAM_MOVEMENT_FAILED\x10 \x12\x17\n\x13STREAM_SETUP_FAILED\x10!\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\"\x12\x1f\n\x1bSTREAM_MOVEMENT_INTERRUPTED\x10#\x12\x16\n\x12INVALID_PARK_STATE\x10$\x12\x14\n\x10SERIAL_PORT_BUSY\x10%\x12\x1a\n\x16TRANSPORT_ALREADY_USED\x10&\x12\x1f\n\x1bSET_PERIPHERAL_STATE_FAILED\x10\'\x12\x1b\n\x17SET_DEVICE_STATE_FAILED\x10(\x12\x11\n\rG_CODE_SYNTAX\x10)\x12\x14\n\x10G_CODE_EXECUTION\x10*\x12\x15\n\x11INVALID_OPERATION\x10+*Q\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\x07\n\x03IOT\x10\x03\x12\x11\n\rNETWORK_SHARE\x10\x04\x42$Z\"./protobufs;zaber_motion_protobufsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobufs.main_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"./protobufs;zaber_motion_protobufs'
  _MESSAGETYPE._serialized_start=23238
  _MESSAGETYPE._serialized_end=23283
  _ERRORS._serialized_start=23286
  _ERRORS._serialized_end=24257
  _INTERFACETYPE._serialized_start=24259
  _INTERFACETYPE._serialized_end=24340
  _REQUEST._serialized_start=48
  _REQUEST._serialized_end=74
  _RESPONSE._serialized_start=77
  _RESPONSE._serialized_end=262
  _RESPONSE_RESPONSETYPE._serialized_start=229
  _RESPONSE_RESPONSETYPE._serialized_end=262
  _EVENT._serialized_start=264
  _EVENT._serialized_end=286
  _EMPTYREQUEST._serialized_start=288
  _EMPTYREQUEST._serialized_end=302
  _AXISIDENTITY._serialized_start=305
  _AXISIDENTITY._serialized_end=526
  _AXISIDENTITY_AXISTYPE._serialized_start=479
  _AXISIDENTITY_AXISTYPE._serialized_end=526
  _DEVICEIDENTITY._serialized_start=529
  _DEVICEIDENTITY._serialized_end=732
  _FIRMWAREVERSION._serialized_start=734
  _FIRMWAREVERSION._serialized_end=796
  _DEVICEIOINFO._serialized_start=799
  _DEVICEIOINFO._serialized_end=937
  _MEASUREMENT._serialized_start=939
  _MEASUREMENT._serialized_end=981
  _STREAMAXISDEFINITION._serialized_start=983
  _STREAMAXISDEFINITION._serialized_end=1045
  _INVALIDPACKETEXCEPTIONDATA._serialized_start=1047
  _INVALIDPACKETEXCEPTIONDATA._serialized_end=1107
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_start=1109
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_end=1171
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1173
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1241
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1243
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1317
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1319
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1382
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1384
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1453
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_start=1455
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_end=1521
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_start=1523
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_end=1571
  _COMMANDFAILEDEXCEPTIONDATA._serialized_start=1573
  _COMMANDFAILEDEXCEPTIONDATA._serialized_end=1682
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_start=1684
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_end=1741
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_start=1743
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_end=1854
  _SETDEVICESTATEEXCEPTIONDATA._serialized_start=1857
  _SETDEVICESTATEEXCEPTIONDATA._serialized_end=2082
  _TESTREQUEST._serialized_start=2084
  _TESTREQUEST._serialized_end=2170
  _TESTRESPONSE._serialized_start=2172
  _TESTRESPONSE._serialized_end=2205
  _TESTRESPONSELONG._serialized_start=2207
  _TESTRESPONSELONG._serialized_end=2244
  _TESTEVENT._serialized_start=2246
  _TESTEVENT._serialized_end=2271
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_start=2273
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_end=2318
  _GETMESSAGEROUTERPIPERESPONSE._serialized_start=2320
  _GETMESSAGEROUTERPIPERESPONSE._serialized_end=2365
  _SETDEVICEDBSOURCEREQUEST._serialized_start=2367
  _SETDEVICEDBSOURCEREQUEST._serialized_end=2440
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_start=2442
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_end=2513
  _OPENINTERFACEREQUEST._serialized_start=2516
  _OPENINTERFACEREQUEST._serialized_end=2811
  _OPENINTERFACERESPONSE._serialized_start=2813
  _OPENINTERFACERESPONSE._serialized_end=2858
  _CLOSEINTERFACEREQUEST._serialized_start=2860
  _CLOSEINTERFACEREQUEST._serialized_end=2905
  _EMPTYINTERFACEREQUEST._serialized_start=2907
  _EMPTYINTERFACEREQUEST._serialized_end=2952
  _GETINTERFACETIMEOUTRESPONSE._serialized_start=2954
  _GETINTERFACETIMEOUTRESPONSE._serialized_end=2998
  _SETINTERFACETIMEOUTREQUEST._serialized_start=3000
  _SETINTERFACETIMEOUTREQUEST._serialized_end=3067
  _GETINTERFACECHECKSUMENABLEDRESPONSE._serialized_start=3069
  _GETINTERFACECHECKSUMENABLEDRESPONSE._serialized_end=3121
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_start=3123
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_end=3201
  _TOSTRINGREQUEST._serialized_start=3203
  _TOSTRINGREQUEST._serialized_end=3272
  _TOSTRINGRESPONSE._serialized_start=3274
  _TOSTRINGRESPONSE._serialized_end=3308
  _GENERICCOMMANDREQUEST._serialized_start=3311
  _GENERICCOMMANDREQUEST._serialized_end=3442
  _GENERICCOMMANDRESPONSE._serialized_start=3445
  _GENERICCOMMANDRESPONSE._serialized_end=3645
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_start=3647
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_end=3748
  _UNKNOWNRESPONSEEVENT._serialized_start=3751
  _UNKNOWNRESPONSEEVENT._serialized_end=3971
  _ALERTEVENT._serialized_start=3974
  _ALERTEVENT._serialized_end=4105
  _DISCONNECTEDEVENT._serialized_start=4107
  _DISCONNECTEDEVENT._serialized_end=4223
  _DEVICERENUMBERREQUEST._serialized_start=4225
  _DEVICERENUMBERREQUEST._serialized_end=4293
  _DEVICERENUMBERRESPONSE._serialized_start=4295
  _DEVICERENUMBERRESPONSE._serialized_end=4343
  _DEVICEDETECTREQUEST._serialized_start=4345
  _DEVICEDETECTREQUEST._serialized_end=4414
  _DEVICEDETECTRESPONSE._serialized_start=4416
  _DEVICEDETECTRESPONSE._serialized_end=4455
  _DEVICEHOMEREQUEST._serialized_start=4457
  _DEVICEHOMEREQUEST._serialized_end=4553
  _DEVICEWAITUNTILIDLEREQUEST._serialized_start=4555
  _DEVICEWAITUNTILIDLEREQUEST._serialized_end=4665
  _DEVICEMOVEREQUEST._serialized_start=4668
  _DEVICEMOVEREQUEST._serialized_end=4914
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_start=4859
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_end=4914
  _DEVICESTOPREQUEST._serialized_start=4916
  _DEVICESTOPREQUEST._serialized_end=5012
  _DEVICEIDENTIFYREQUEST._serialized_start=5014
  _DEVICEIDENTIFYREQUEST._serialized_end=5075
  _DEVICEONALLREQUEST._serialized_start=5077
  _DEVICEONALLREQUEST._serialized_end=5144
  _DEVICEONALLRESPONSE._serialized_start=5146
  _DEVICEONALLRESPONSE._serialized_end=5193
  _DEVICEGETIDENTITYREQUEST._serialized_start=5195
  _DEVICEGETIDENTITYREQUEST._serialized_end=5259
  _DEVICEGETIDENTITYRESPONSE._serialized_start=5261
  _DEVICEGETIDENTITYRESPONSE._serialized_end=5346
  _DEVICEGETISIDENTIFIEDREQUEST._serialized_start=5348
  _DEVICEGETISIDENTIFIEDREQUEST._serialized_end=5416
  _DEVICEGETISIDENTIFIEDRESPONSE._serialized_start=5418
  _DEVICEGETISIDENTIFIEDRESPONSE._serialized_end=5472
  _DEVICEGETAXISIDENTITYREQUEST._serialized_start=5474
  _DEVICEGETAXISIDENTITYREQUEST._serialized_end=5556
  _DEVICEGETAXISIDENTITYRESPONSE._serialized_start=5558
  _DEVICEGETAXISIDENTITYRESPONSE._serialized_end=5645
  _DEVICEISBUSYREQUEST._serialized_start=5647
  _DEVICEISBUSYREQUEST._serialized_end=5720
  _DEVICEISBUSYRESPONSE._serialized_start=5722
  _DEVICEISBUSYRESPONSE._serialized_end=5761
  _DEVICEGETWARNINGSREQUEST._serialized_start=5763
  _DEVICEGETWARNINGSREQUEST._serialized_end=5856
  _DEVICEGETWARNINGSRESPONSE._serialized_start=5858
  _DEVICEGETWARNINGSRESPONSE._serialized_end=5900
  _DEVICEGETALLDIGITALIOREQUEST._serialized_start=5902
  _DEVICEGETALLDIGITALIOREQUEST._serialized_end=5992
  _DEVICEGETALLDIGITALIORESPONSE._serialized_start=5994
  _DEVICEGETALLDIGITALIORESPONSE._serialized_end=6041
  _DEVICEGETALLANALOGIOREQUEST._serialized_start=6043
  _DEVICEGETALLANALOGIOREQUEST._serialized_end=6132
  _DEVICEGETALLANALOGIORESPONSE._serialized_start=6134
  _DEVICEGETALLANALOGIORESPONSE._serialized_end=6180
  _DEVICEGETDIGITALIOREQUEST._serialized_start=6182
  _DEVICEGETDIGITALIOREQUEST._serialized_end=6293
  _DEVICEGETDIGITALIORESPONSE._serialized_start=6295
  _DEVICEGETDIGITALIORESPONSE._serialized_end=6338
  _DEVICEGETANALOGIOREQUEST._serialized_start=6340
  _DEVICEGETANALOGIOREQUEST._serialized_end=6450
  _DEVICEGETANALOGIORESPONSE._serialized_start=6452
  _DEVICEGETANALOGIORESPONSE._serialized_end=6494
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_start=6496
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_end=6585
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_start=6587
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_end=6675
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_start=6677
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_end=6785
  _DEVICESETANALOGOUTPUTREQUEST._serialized_start=6787
  _DEVICESETANALOGOUTPUTREQUEST._serialized_end=6894
  _DEVICEGETIOCHANNELSINFOREQUEST._serialized_start=6896
  _DEVICEGETIOCHANNELSINFOREQUEST._serialized_end=6966
  _SETLOGOUTPUTREQUEST._serialized_start=6968
  _SETLOGOUTPUTREQUEST._serialized_end=7022
  _DEVICEGETSETTINGREQUEST._serialized_start=7024
  _DEVICEGETSETTINGREQUEST._serialized_end=7132
  _DEVICEGETSETTINGRESPONSE._serialized_start=7134
  _DEVICEGETSETTINGRESPONSE._serialized_end=7175
  _DEVICEGETSETTINGSTRRESPONSE._serialized_start=7177
  _DEVICEGETSETTINGSTRRESPONSE._serialized_end=7221
  _DEVICECONVERTSETTINGREQUEST._serialized_start=7224
  _DEVICECONVERTSETTINGREQUEST._serialized_end=7372
  _DEVICECONVERTSETTINGRESPONSE._serialized_start=7374
  _DEVICECONVERTSETTINGRESPONSE._serialized_end=7419
  _DEVICESETSETTINGREQUEST._serialized_start=7421
  _DEVICESETSETTINGREQUEST._serialized_end=7544
  _DEVICESETSETTINGSTRREQUEST._serialized_start=7546
  _DEVICESETSETTINGSTRREQUEST._serialized_end=7658
  _PREPARECOMMANDREQUEST._serialized_start=7661
  _PREPARECOMMANDREQUEST._serialized_end=7819
  _PREPARECOMMANDRESPONSE._serialized_start=7821
  _PREPARECOMMANDRESPONSE._serialized_end=7862
  _DEVICEPARKREQUEST._serialized_start=7864
  _DEVICEPARKREQUEST._serialized_end=7935
  _DEVICEISPARKEDRESPONSE._serialized_start=7937
  _DEVICEISPARKEDRESPONSE._serialized_end=7980
  _LOCKSTEPENABLEREQUEST._serialized_start=7982
  _LOCKSTEPENABLEREQUEST._serialized_end=8084
  _LOCKSTEPDISABLEREQUEST._serialized_start=8086
  _LOCKSTEPDISABLEREQUEST._serialized_end=8200
  _LOCKSTEPSTOPREQUEST._serialized_start=8202
  _LOCKSTEPSTOPREQUEST._serialized_end=8313
  _LOCKSTEPHOMEREQUEST._serialized_start=8315
  _LOCKSTEPHOMEREQUEST._serialized_end=8426
  _LOCKSTEPMOVEREQUEST._serialized_start=8429
  _LOCKSTEPMOVEREQUEST._serialized_end=8692
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_start=4859
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_end=4914
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_start=8694
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_end=8819
  _LOCKSTEPISBUSYREQUEST._serialized_start=8821
  _LOCKSTEPISBUSYREQUEST._serialized_end=8909
  _LOCKSTEPISBUSYRESPONSE._serialized_start=8911
  _LOCKSTEPISBUSYRESPONSE._serialized_end=8952
  _LOCKSTEPGETAXESREQUEST._serialized_start=8954
  _LOCKSTEPGETAXESREQUEST._serialized_end=9043
  _LOCKSTEPAXES._serialized_start=9045
  _LOCKSTEPAXES._serialized_end=9123
  _LOCKSTEPGETAXESRESPONSE._serialized_start=9125
  _LOCKSTEPGETAXESRESPONSE._serialized_end=9202
  _LOCKSTEPGETAXISNUMBERSREQUEST._serialized_start=9204
  _LOCKSTEPGETAXISNUMBERSREQUEST._serialized_end=9300
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_start=9302
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_end=9348
  _LOCKSTEPGETTWISTSREQUEST._serialized_start=9350
  _LOCKSTEPGETTWISTSREQUEST._serialized_end=9455
  _LOCKSTEPGETTWISTSRESPONSE._serialized_start=9457
  _LOCKSTEPGETTWISTSRESPONSE._serialized_end=9500
  _LOCKSTEPGETOFFSETSREQUEST._serialized_start=9502
  _LOCKSTEPGETOFFSETSREQUEST._serialized_end=9608
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_start=9610
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_end=9655
  _LOCKSTEPISENABLEDREQUEST._serialized_start=9657
  _LOCKSTEPISENABLEDREQUEST._serialized_end=9748
  _LOCKSTEPISENABLEDRESPONSE._serialized_start=9750
  _LOCKSTEPISENABLEDRESPONSE._serialized_end=9797
  _LOCKSTEPTOSTRINGREQUEST._serialized_start=9799
  _LOCKSTEPTOSTRINGREQUEST._serialized_end=9889
  _LOCKSTEPTOSTRINGRESPONSE._serialized_start=9891
  _LOCKSTEPTOSTRINGRESPONSE._serialized_end=9933
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_start=9935
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_end=10035
  _OSCILLOSCOPECLEARCHANNELSREQUEST._serialized_start=10037
  _OSCILLOSCOPECLEARCHANNELSREQUEST._serialized_end=10109
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_start=10111
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_end=10194
  _OSCILLOSCOPEREADREQUEST._serialized_start=10196
  _OSCILLOSCOPEREADREQUEST._serialized_end=10259
  _OSCILLOSCOPEREADRESPONSE._serialized_start=10261
  _OSCILLOSCOPEREADRESPONSE._serialized_end=10305
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_start=10307
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_end=10390
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_start=10392
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_end=10461
  _OSCILLOSCOPEDATAGETPROPERTIESRESPONSE._serialized_start=10463
  _OSCILLOSCOPEDATAGETPROPERTIESRESPONSE._serialized_end=10577
  _OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST._serialized_start=10579
  _OSCILLOSCOPEDATAGETSAVEDSETTINGREQUEST._serialized_end=10688
  _OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE._serialized_start=10690
  _OSCILLOSCOPEDATAGETSAVEDSETTINGRESPONSE._serialized_end=10746
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_start=10748
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_end=10870
  _OSCILLOSCOPEDATAGETSAMPLESREQUEST._serialized_start=10872
  _OSCILLOSCOPEDATAGETSAMPLESREQUEST._serialized_end=10976
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_start=10978
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_end=11028
  _STREAMSETUPLIVEREQUEST._serialized_start=11030
  _STREAMSETUPLIVEREQUEST._serialized_end=11125
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_start=11128
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_end=11278
  _STREAMSETUPSTOREREQUEST._serialized_start=11280
  _STREAMSETUPSTOREREQUEST._serialized_end=11399
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_start=11402
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_end=11576
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_start=11579
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_end=11717
  _STREAMCALLREQUEST._serialized_start=11719
  _STREAMCALLREQUEST._serialized_end=11818
  _STREAMLINEREQUEST._serialized_start=11821
  _STREAMLINEREQUEST._serialized_end=12069
  _STREAMLINEREQUEST_TYPE._serialized_start=12045
  _STREAMLINEREQUEST_TYPE._serialized_end=12069
  _STREAMARCREQUEST._serialized_start=12072
  _STREAMARCREQUEST._serialized_end=12505
  _STREAMARCREQUEST_TYPE._serialized_start=12045
  _STREAMARCREQUEST_TYPE._serialized_end=12069
  _STREAMCIRCLEREQUEST._serialized_start=12508
  _STREAMCIRCLEREQUEST._serialized_end=12843
  _STREAMCIRCLEREQUEST_TYPE._serialized_start=12045
  _STREAMCIRCLEREQUEST_TYPE._serialized_end=12069
  _STREAMWAITDIGITALINPUTREQUEST._serialized_start=12845
  _STREAMWAITDIGITALINPUTREQUEST._serialized_end=12972
  _STREAMWAITANALOGINPUTREQUEST._serialized_start=12975
  _STREAMWAITANALOGINPUTREQUEST._serialized_end=13120
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_start=13122
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_end=13249
  _STREAMSETANALOGOUTPUTREQUEST._serialized_start=13251
  _STREAMSETANALOGOUTPUTREQUEST._serialized_end=13377
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_start=13379
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_end=13494
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_start=13496
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_end=13604
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_start=13606
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_end=13713
  _STREAMWAITREQUEST._serialized_start=13715
  _STREAMWAITREQUEST._serialized_end=13819
  _STREAMWAITUNTILIDLEREQUEST._serialized_start=13821
  _STREAMWAITUNTILIDLEREQUEST._serialized_end=13936
  _STREAMCORKREQUEST._serialized_start=13938
  _STREAMCORKREQUEST._serialized_end=14014
  _STREAMUNCORKREQUEST._serialized_start=14016
  _STREAMUNCORKREQUEST._serialized_end=14094
  _STREAMISBUSYREQUEST._serialized_start=14096
  _STREAMISBUSYREQUEST._serialized_end=14174
  _STREAMISBUSYRESPONSE._serialized_start=14176
  _STREAMISBUSYRESPONSE._serialized_end=14215
  _STREAMGETAXESREQUEST._serialized_start=14217
  _STREAMGETAXESREQUEST._serialized_end=14296
  _STREAMGETAXESRESPONSE._serialized_start=14298
  _STREAMGETAXESRESPONSE._serialized_end=14381
  _STREAMGETMODEREQUEST._serialized_start=14383
  _STREAMGETMODEREQUEST._serialized_end=14462
  _STREAMGETMODERESPONSE._serialized_start=14464
  _STREAMGETMODERESPONSE._serialized_end=14501
  _STREAMGETMAXSPEEDREQUEST._serialized_start=14503
  _STREAMGETMAXSPEEDREQUEST._serialized_end=14600
  _STREAMGETMAXSPEEDRESPONSE._serialized_start=14602
  _STREAMGETMAXSPEEDRESPONSE._serialized_end=14648
  _STREAMSETMAXSPEEDREQUEST._serialized_start=14650
  _STREAMSETMAXSPEEDREQUEST._serialized_end=14766
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=14768
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=14882
  _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE._serialized_start=14884
  _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE._serialized_end=14965
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=14968
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=15119
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=15121
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=15236
  _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE._serialized_start=15238
  _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE._serialized_end=15321
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=15324
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=15477
  _STREAMTOSTRINGREQUEST._serialized_start=15479
  _STREAMTOSTRINGREQUEST._serialized_end=15559
  _STREAMTOSTRINGRESPONSE._serialized_start=15561
  _STREAMTOSTRINGRESPONSE._serialized_end=15601
  _STREAMDISABLEREQUEST._serialized_start=15603
  _STREAMDISABLEREQUEST._serialized_end=15682
  _STREAMBUFFERGETCONTENTREQUEST._serialized_start=15684
  _STREAMBUFFERGETCONTENTREQUEST._serialized_end=15772
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_start=15774
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_end=15828
  _STREAMBUFFERERASEREQUEST._serialized_start=15830
  _STREAMBUFFERERASEREQUEST._serialized_end=15913
  _STREAMGENERICCOMMANDREQUEST._serialized_start=15915
  _STREAMGENERICCOMMANDREQUEST._serialized_end=16018
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_start=16020
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_end=16126
  _BINARYREPLYONLYEVENT._serialized_start=16128
  _BINARYREPLYONLYEVENT._serialized_end=16227
  _OPENBINARYINTERFACEREQUEST._serialized_start=16230
  _OPENBINARYINTERFACEREQUEST._serialized_end=16417
  _UNKNOWNBINARYRESPONSEEVENT._serialized_start=16419
  _UNKNOWNBINARYRESPONSEEVENT._serialized_end=16524
  _GENERICBINARYREQUEST._serialized_start=16527
  _GENERICBINARYREQUEST._serialized_end=16657
  _BINARYMESSAGE._serialized_start=16659
  _BINARYMESSAGE._serialized_end=16729
  _BINARYMESSAGECOLLECTION._serialized_start=16731
  _BINARYMESSAGECOLLECTION._serialized_end=16813
  _BINARYDEVICERENUMBERREQUEST._serialized_start=16815
  _BINARYDEVICERENUMBERREQUEST._serialized_end=16866
  _BINARYDEVICERENUMBERRESPONSE._serialized_start=16868
  _BINARYDEVICERENUMBERRESPONSE._serialized_end=16922
  _BINARYDEVICEIDENTIFYREQUEST._serialized_start=16924
  _BINARYDEVICEIDENTIFYREQUEST._serialized_end=16991
  _BINARYDEVICEIDENTITY._serialized_start=16994
  _BINARYDEVICEIDENTITY._serialized_end=17339
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_start=17290
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_end=17339
  _BINARYDEVICEGETIDENTITYREQUEST._serialized_start=17341
  _BINARYDEVICEGETIDENTITYREQUEST._serialized_end=17411
  _BINARYDEVICEGETIDENTITYRESPONSE._serialized_start=17413
  _BINARYDEVICEGETIDENTITYRESPONSE._serialized_end=17510
  _BINARYDEVICEGETISIDENTIFIEDREQUEST._serialized_start=17512
  _BINARYDEVICEGETISIDENTIFIEDREQUEST._serialized_end=17586
  _BINARYDEVICEGETISIDENTIFIEDRESPONSE._serialized_start=17588
  _BINARYDEVICEGETISIDENTIFIEDRESPONSE._serialized_end=17648
  _BINARYGENERICWITHUNITSREQUEST._serialized_start=17651
  _BINARYGENERICWITHUNITSREQUEST._serialized_end=17804
  _BINARYGENERICWITHUNITSRESPONSE._serialized_start=17806
  _BINARYGENERICWITHUNITSRESPONSE._serialized_end=17852
  _BINARYDEVICEHOMEREQUEST._serialized_start=17854
  _BINARYDEVICEHOMEREQUEST._serialized_end=17948
  _BINARYDEVICEMOVEMENTRESPONSE._serialized_start=17950
  _BINARYDEVICEMOVEMENTRESPONSE._serialized_end=17994
  _BINARYDEVICEMOVEREQUEST._serialized_start=17997
  _BINARYDEVICEMOVEREQUEST._serialized_end=18215
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_start=4859
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_end=4896
  _BINARYDEVICESTOPREQUEST._serialized_start=18217
  _BINARYDEVICESTOPREQUEST._serialized_end=18311
  _BINARYDEVICEWAITUNTILIDLEREQUEST._serialized_start=18313
  _BINARYDEVICEWAITUNTILIDLEREQUEST._serialized_end=18385
  _BINARYDEVICEISBUSYREQUEST._serialized_start=18387
  _BINARYDEVICEISBUSYREQUEST._serialized_end=18452
  _BINARYDEVICEISBUSYRESPONSE._serialized_start=18454
  _BINARYDEVICEISBUSYRESPONSE._serialized_end=18499
  _BINARYDEVICEDETECTREQUEST._serialized_start=18501
  _BINARYDEVICEDETECTREQUEST._serialized_end=18576
  _BINARYDEVICEDETECTRESPONSE._serialized_start=18578
  _BINARYDEVICEDETECTRESPONSE._serialized_end=18623
  _BINARYDEVICEGETSETTINGREQUEST._serialized_start=18625
  _BINARYDEVICEGETSETTINGREQUEST._serialized_end=18725
  _BINARYDEVICEGETSETTINGRESPONSE._serialized_start=18727
  _BINARYDEVICEGETSETTINGRESPONSE._serialized_end=18774
  _BINARYDEVICESETSETTINGREQUEST._serialized_start=18776
  _BINARYDEVICESETSETTINGREQUEST._serialized_end=18891
  _BINARYDEVICEPARKREQUEST._serialized_start=18893
  _BINARYDEVICEPARKREQUEST._serialized_end=18956
  _BINARYDEVICEPARKRESPONSE._serialized_start=18958
  _BINARYDEVICEPARKRESPONSE._serialized_end=19003
  _CUSTOMINTERFACEREADREQUEST._serialized_start=19005
  _CUSTOMINTERFACEREADREQUEST._serialized_end=19055
  _CUSTOMINTERFACEREADRESPONSE._serialized_start=19057
  _CUSTOMINTERFACEREADRESPONSE._serialized_end=19103
  _CUSTOMINTERFACEWRITEREQUEST._serialized_start=19105
  _CUSTOMINTERFACEWRITEREQUEST._serialized_end=19173
  _CUSTOMINTERFACEOPENRESPONSE._serialized_start=19175
  _CUSTOMINTERFACEOPENRESPONSE._serialized_end=19226
  _CUSTOMINTERFACECLOSEREQUEST._serialized_start=19228
  _CUSTOMINTERFACECLOSEREQUEST._serialized_end=19302
  _GETSTATEREQUEST._serialized_start=19304
  _GETSTATEREQUEST._serialized_end=19373
  _GETSTATERESPONSE._serialized_start=19375
  _GETSTATERESPONSE._serialized_end=19408
  _CANSETSTATEREQUEST._serialized_start=19410
  _CANSETSTATEREQUEST._serialized_end=19518
  _CANSETSTATEAXISRESPONSE._serialized_start=19520
  _CANSETSTATEAXISRESPONSE._serialized_end=19581
  _CANSETSTATEDEVICERESPONSE._serialized_start=19583
  _CANSETSTATEDEVICERESPONSE._serialized_end=19701
  _SETSTATEREQUEST._serialized_start=19703
  _SETSTATEREQUEST._serialized_end=19808
  _SERVOTUNINGREQUEST._serialized_start=19810
  _SERVOTUNINGREQUEST._serialized_end=19900
  _SERVOTUNINGPARAM._serialized_start=19902
  _SERVOTUNINGPARAM._serialized_end=19949
  _PARAMSETINFO._serialized_start=19951
  _PARAMSETINFO._serialized_end=20037
  _SETSERVOTUNINGREQUEST._serialized_start=20040
  _SETSERVOTUNINGREQUEST._serialized_end=20198
  _GETSTARTUPPARAMSET._serialized_start=20200
  _GETSTARTUPPARAMSET._serialized_end=20272
  _STARTUPPARAMSET._serialized_start=20274
  _STARTUPPARAMSET._serialized_end=20309
  _LOADPARAMSET._serialized_start=20311
  _LOADPARAMSET._serialized_end=20421
  _SETSERVOTUNINGPIDREQUEST._serialized_start=20424
  _SETSERVOTUNINGPIDREQUEST._serialized_end=20565
  _PIDTUNING._serialized_start=20567
  _PIDTUNING._serialized_end=20654
  _GETSIMPLETUNINGPARAMLISTREQUEST._serialized_start=20656
  _GETSIMPLETUNINGPARAMLISTREQUEST._serialized_end=20741
  _SETSIMPLETUNING._serialized_start=20744
  _SETSIMPLETUNING._serialized_end=20938
  _SIMPLETUNINGPARAM._serialized_start=20940
  _SIMPLETUNINGPARAM._serialized_end=21030
  _SIMPLETUNINGPARAMLIST._serialized_start=21032
  _SIMPLETUNINGPARAMLIST._serialized_end=21114
  _TRANSLATORCREATEREQUEST._serialized_start=21117
  _TRANSLATORCREATEREQUEST._serialized_end=21266
  _TRANSLATORCREATERESPONSE._serialized_start=21268
  _TRANSLATORCREATERESPONSE._serialized_end=21317
  _TRANSLATORAXISDEFINITION._serialized_start=21319
  _TRANSLATORAXISDEFINITION._serialized_end=21398
  _TRANSLATORDEFINITION._serialized_start=21401
  _TRANSLATORDEFINITION._serialized_end=21562
  _TRANSLATORCONFIG._serialized_start=21565
  _TRANSLATORCONFIG._serialized_end=21737
  _TRANSLATORAXISMAPPING._serialized_start=21739
  _TRANSLATORAXISMAPPING._serialized_end=21803
  _TRANSLATORAXISTRANSFORMATION._serialized_start=21805
  _TRANSLATORAXISTRANSFORMATION._serialized_end=21931
  _TRANSLATORTRANSLATEREQUEST._serialized_start=21933
  _TRANSLATORTRANSLATEREQUEST._serialized_end=21999
  _TRANSLATEMESSAGE._serialized_start=22001
  _TRANSLATEMESSAGE._serialized_end=22074
  _TRANSLATORTRANSLATERESPONSE._serialized_start=22076
  _TRANSLATORTRANSLATERESPONSE._serialized_end=22183
  _GCODESYNTAXEXCEPTIONDATA._serialized_start=22185
  _GCODESYNTAXEXCEPTIONDATA._serialized_end=22249
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_start=22251
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_end=22318
  _TRANSLATORFLUSHLIVEREQUEST._serialized_start=22320
  _TRANSLATORFLUSHLIVEREQUEST._serialized_end=22396
  _TRANSLATORFLUSHRESPONSE._serialized_start=22398
  _TRANSLATORFLUSHRESPONSE._serialized_end=22441
  _TRANSLATORCREATELIVEREQUEST._serialized_start=22444
  _TRANSLATORCREATELIVEREQUEST._serialized_end=22588
  _TRANSLATOREMPTYREQUEST._serialized_start=22590
  _TRANSLATOREMPTYREQUEST._serialized_end=22637
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_start=22639
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_end=22733
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_start=22735
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_end=22838
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_start=22840
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_end=22925
  _TRANSLATORGETAXISPOSITIONRESPONSE._serialized_start=22927
  _TRANSLATORGETAXISPOSITIONRESPONSE._serialized_end=22977
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_start=22979
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_end=23089
  _TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE._serialized_start=23091
  _TRANSLATORGETCURRENTCOORDINATESYSTEMRESPONSE._serialized_end=23152
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_start=23154
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_end=23236
# @@protoc_insertion_point(module_scope)



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
# pylint: disable=W0201

from typing import List  # pylint: disable=unused-import
from ..protobufs import main_pb2
from .set_peripheral_state_exception_data import SetPeripheralStateExceptionData


class SetDeviceStateExceptionData:
    """
    Contains additional data for a SetDeviceStateFailedException.
    """

    @property
    def settings(self) -> List[str]:
        """
        A list of settings which could not be set.
        """

        return self._settings

    @settings.setter
    def settings(self, value: List[str]) -> None:
        self._settings = value

    @property
    def stream_buffers(self) -> List[str]:
        """
        The reason the stream buffers could not be set.
        """

        return self._stream_buffers

    @stream_buffers.setter
    def stream_buffers(self, value: List[str]) -> None:
        self._stream_buffers = value

    @property
    def triggers(self) -> List[str]:
        """
        The reason the triggers could not be set.
        """

        return self._triggers

    @triggers.setter
    def triggers(self, value: List[str]) -> None:
        self._triggers = value

    @property
    def peripherals(self) -> List[SetPeripheralStateExceptionData]:
        """
        Errors for any peripherals that could not be set.
        """

        return self._peripherals

    @peripherals.setter
    def peripherals(self, value: List[SetPeripheralStateExceptionData]) -> None:
        self._peripherals = value

    def __repr__(self) -> str:
        return str(self.__dict__)

    @staticmethod
    def from_protobuf(
        pb_data: main_pb2.SetDeviceStateExceptionData
    ) -> 'SetDeviceStateExceptionData':
        instance = SetDeviceStateExceptionData.__new__(
            SetDeviceStateExceptionData
        )  # type: SetDeviceStateExceptionData
        instance.settings = list(pb_data.settings)
        instance.stream_buffers = list(pb_data.stream_buffers)
        instance.triggers = list(pb_data.triggers)
        instance.peripherals = [SetPeripheralStateExceptionData.from_protobuf(item) for item in pb_data.peripherals]
        return instance



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #


class SettingConstants:

    """
    Accel.
    """
    ACCEL = "accel"

    """
    Calibration Type.
    """
    CALIBRATION_TYPE = "calibration.type"

    """
    Cloop Continuous Enable.
    """
    CLOOP_CONTINUOUS_ENABLE = "cloop.continuous.enable"

    """
    Cloop Counts.
    """
    CLOOP_COUNTS = "cloop.counts"

    """
    Cloop Displace Tolerance.
    """
    CLOOP_DISPLACE_TOLERANCE = "cloop.displace.tolerance"

    """
    Cloop Duration Max.
    """
    CLOOP_DURATION_MAX = "cloop.duration.max"

    """
    Cloop Enable.
    """
    CLOOP_ENABLE = "cloop.enable"

    """
    Cloop Mode.
    """
    CLOOP_MODE = "cloop.mode"

    """
    Cloop Recovery Enable.
    """
    CLOOP_RECOVERY_ENABLE = "cloop.recovery.enable"

    """
    Cloop Servo Enable.
    """
    CLOOP_SERVO_ENABLE = "cloop.servo.enable"

    """
    Cloop Settle Period.
    """
    CLOOP_SETTLE_PERIOD = "cloop.settle.period"

    """
    Cloop Settle Tolerance.
    """
    CLOOP_SETTLE_TOLERANCE = "cloop.settle.tolerance"

    """
    Cloop Stalltimeout.
    """
    CLOOP_STALLTIMEOUT = "cloop.stalltimeout"

    """
    Cloop Steps.
    """
    CLOOP_STEPS = "cloop.steps"

    """
    Cloop Timeout.
    """
    CLOOP_TIMEOUT = "cloop.timeout"

    """
    Comm Address.
    """
    COMM_ADDRESS = "comm.address"

    """
    Comm Alert.
    """
    COMM_ALERT = "comm.alert"

    """
    Comm Checksum.
    """
    COMM_CHECKSUM = "comm.checksum"

    """
    Comm En Ipv 4 Address.
    """
    COMM_EN_IPV_4_ADDRESS = "comm.en.ipv4.address"

    """
    Comm En Ipv 4 Dhcp Enabled.
    """
    COMM_EN_IPV_4_DHCP_ENABLED = "comm.en.ipv4.dhcp.enabled"

    """
    Comm En Ipv 4 Gateway.
    """
    COMM_EN_IPV_4_GATEWAY = "comm.en.ipv4.gateway"

    """
    Comm En Ipv 4 Netmask.
    """
    COMM_EN_IPV_4_NETMASK = "comm.en.ipv4.netmask"

    """
    Comm En Mdns Enable.
    """
    COMM_EN_MDNS_ENABLE = "comm.en.mdns.enable"

    """
    Comm Protocol.
    """
    COMM_PROTOCOL = "comm.protocol"

    """
    Comm Rs 232 Baud.
    """
    COMM_RS_232_BAUD = "comm.rs232.baud"

    """
    Comm Rs 232 Protocol.
    """
    COMM_RS_232_PROTOCOL = "comm.rs232.protocol"

    """
    Comm Rs 485 Baud.
    """
    COMM_RS_485_BAUD = "comm.rs485.baud"

    """
    Comm Rs 485 Enable.
    """
    COMM_RS_485_ENABLE = "comm.rs485.enable"

    """
    Comm Rs 485 Protocol.
    """
    COMM_RS_485_PROTOCOL = "comm.rs485.protocol"

    """
    Comm Usb Protocol.
    """
    COMM_USB_PROTOCOL = "comm.usb.protocol"

    """
    Device Hw Modified.
    """
    DEVICE_HW_MODIFIED = "device.hw.modified"

    """
    Deviceid.
    """
    DEVICEID = "deviceid"

    """
    Driver Current Hold.
    """
    DRIVER_CURRENT_HOLD = "driver.current.hold"

    """
    Driver Current Max.
    """
    DRIVER_CURRENT_MAX = "driver.current.max"

    """
    Driver Current Run.
    """
    DRIVER_CURRENT_RUN = "driver.current.run"

    """
    Driver Current Servo.
    """
    DRIVER_CURRENT_SERVO = "driver.current.servo"

    """
    Driver Dir.
    """
    DRIVER_DIR = "driver.dir"

    """
    Driver Enabled.
    """
    DRIVER_ENABLED = "driver.enabled"

    """
    Driver Temperature.
    """
    DRIVER_TEMPERATURE = "driver.temperature"

    """
    Encoder 1 Count.
    """
    ENCODER_1_COUNT = "encoder.1.count"

    """
    Encoder 1 Count Cal.
    """
    ENCODER_1_COUNT_CAL = "encoder.1.count.cal"

    """
    Encoder 1 Dir.
    """
    ENCODER_1_DIR = "encoder.1.dir"

    """
    Encoder 1 Fault Type.
    """
    ENCODER_1_FAULT_TYPE = "encoder.1.fault.type"

    """
    Encoder 1 Filter.
    """
    ENCODER_1_FILTER = "encoder.1.filter"

    """
    Encoder 1 Index Mode.
    """
    ENCODER_1_INDEX_MODE = "encoder.1.index.mode"

    """
    Encoder 1 Mode.
    """
    ENCODER_1_MODE = "encoder.1.mode"

    """
    Encoder 1 Pos.
    """
    ENCODER_1_POS = "encoder.1.pos"

    """
    Encoder 1 Pos Error.
    """
    ENCODER_1_POS_ERROR = "encoder.1.pos.error"

    """
    Encoder 1 Ratio Div.
    """
    ENCODER_1_RATIO_DIV = "encoder.1.ratio.div"

    """
    Encoder 1 Ratio Mult.
    """
    ENCODER_1_RATIO_MULT = "encoder.1.ratio.mult"

    """
    Encoder 1 Ref Phase.
    """
    ENCODER_1_REF_PHASE = "encoder.1.ref.phase"

    """
    Encoder 1 Type.
    """
    ENCODER_1_TYPE = "encoder.1.type"

    """
    Encoder 2 Cos.
    """
    ENCODER_2_COS = "encoder.2.cos"

    """
    Encoder 2 Cos Dc.
    """
    ENCODER_2_COS_DC = "encoder.2.cos.dc"

    """
    Encoder 2 Cos Dc Tune.
    """
    ENCODER_2_COS_DC_TUNE = "encoder.2.cos.dc.tune"

    """
    Encoder 2 Cos Gain.
    """
    ENCODER_2_COS_GAIN = "encoder.2.cos.gain"

    """
    Encoder 2 Cos Gain Tune.
    """
    ENCODER_2_COS_GAIN_TUNE = "encoder.2.cos.gain.tune"

    """
    Encoder 2 Count.
    """
    ENCODER_2_COUNT = "encoder.2.count"

    """
    Encoder 2 Count Cal.
    """
    ENCODER_2_COUNT_CAL = "encoder.2.count.cal"

    """
    Encoder 2 Dir.
    """
    ENCODER_2_DIR = "encoder.2.dir"

    """
    Encoder 2 Fault Type.
    """
    ENCODER_2_FAULT_TYPE = "encoder.2.fault.type"

    """
    Encoder 2 Filter.
    """
    ENCODER_2_FILTER = "encoder.2.filter"

    """
    Encoder 2 Index Mode.
    """
    ENCODER_2_INDEX_MODE = "encoder.2.index.mode"

    """
    Encoder 2 Interpolation.
    """
    ENCODER_2_INTERPOLATION = "encoder.2.interpolation"

    """
    Encoder 2 Mode.
    """
    ENCODER_2_MODE = "encoder.2.mode"

    """
    Encoder 2 Pos.
    """
    ENCODER_2_POS = "encoder.2.pos"

    """
    Encoder 2 Pos Error.
    """
    ENCODER_2_POS_ERROR = "encoder.2.pos.error"

    """
    Encoder 2 Ratio Div.
    """
    ENCODER_2_RATIO_DIV = "encoder.2.ratio.div"

    """
    Encoder 2 Ratio Mult.
    """
    ENCODER_2_RATIO_MULT = "encoder.2.ratio.mult"

    """
    Encoder 2 Signal Min.
    """
    ENCODER_2_SIGNAL_MIN = "encoder.2.signal.min"

    """
    Encoder 2 Sin.
    """
    ENCODER_2_SIN = "encoder.2.sin"

    """
    Encoder 2 Sin Dc.
    """
    ENCODER_2_SIN_DC = "encoder.2.sin.dc"

    """
    Encoder 2 Sin Dc Tune.
    """
    ENCODER_2_SIN_DC_TUNE = "encoder.2.sin.dc.tune"

    """
    Encoder 2 Sin Gain.
    """
    ENCODER_2_SIN_GAIN = "encoder.2.sin.gain"

    """
    Encoder 2 Sin Gain Tune.
    """
    ENCODER_2_SIN_GAIN_TUNE = "encoder.2.sin.gain.tune"

    """
    Encoder 2 Type.
    """
    ENCODER_2_TYPE = "encoder.2.type"

    """
    Encoder Count.
    """
    ENCODER_COUNT = "encoder.count"

    """
    Encoder Count Cal.
    """
    ENCODER_COUNT_CAL = "encoder.count.cal"

    """
    Encoder Count Calibrated.
    """
    ENCODER_COUNT_CALIBRATED = "encoder.count.calibrated"

    """
    Encoder Dir.
    """
    ENCODER_DIR = "encoder.dir"

    """
    Encoder Error.
    """
    ENCODER_ERROR = "encoder.error"

    """
    Encoder Fault Type.
    """
    ENCODER_FAULT_TYPE = "encoder.fault.type"

    """
    Encoder Filter.
    """
    ENCODER_FILTER = "encoder.filter"

    """
    Encoder Index Count.
    """
    ENCODER_INDEX_COUNT = "encoder.index.count"

    """
    Encoder Index Mode.
    """
    ENCODER_INDEX_MODE = "encoder.index.mode"

    """
    Encoder Index Phase.
    """
    ENCODER_INDEX_PHASE = "encoder.index.phase"

    """
    Encoder Mode.
    """
    ENCODER_MODE = "encoder.mode"

    """
    Encoder Port Default.
    """
    ENCODER_PORT_DEFAULT = "encoder.port.default"

    """
    Encoder Pos.
    """
    ENCODER_POS = "encoder.pos"

    """
    Encoder Pos Error.
    """
    ENCODER_POS_ERROR = "encoder.pos.error"

    """
    Encoder Ratio Div.
    """
    ENCODER_RATIO_DIV = "encoder.ratio.div"

    """
    Encoder Ratio Mult.
    """
    ENCODER_RATIO_MULT = "encoder.ratio.mult"

    """
    Filter Holderid.
    """
    FILTER_HOLDERID = "filter.holderid"

    """
    Force Average.
    """
    FORCE_AVERAGE = "force.average"

    """
    Io Di Port.
    """
    IO_DI_PORT = "io.di.port"

    """
    Io Do Port.
    """
    IO_DO_PORT = "io.do.port"

    """
    Joy Debug.
    """
    JOY_DEBUG = "joy.debug"

    """
    Knob Dir.
    """
    KNOB_DIR = "knob.dir"

    """
    Knob Distance.
    """
    KNOB_DISTANCE = "knob.distance"

    """
    Knob Enable.
    """
    KNOB_ENABLE = "knob.enable"

    """
    Knob Force.
    """
    KNOB_FORCE = "knob.force"

    """
    Knob Forceprofile.
    """
    KNOB_FORCEPROFILE = "knob.forceprofile"

    """
    Knob Maxspeed.
    """
    KNOB_MAXSPEED = "knob.maxspeed"

    """
    Knob Mode.
    """
    KNOB_MODE = "knob.mode"

    """
    Knob Speedprofile.
    """
    KNOB_SPEEDPROFILE = "knob.speedprofile"

    """
    Lamp Current.
    """
    LAMP_CURRENT = "lamp.current"

    """
    Lamp Current Max.
    """
    LAMP_CURRENT_MAX = "lamp.current.max"

    """
    Lamp Flux.
    """
    LAMP_FLUX = "lamp.flux"

    """
    Lamp Flux Max.
    """
    LAMP_FLUX_MAX = "lamp.flux.max"

    """
    Lamp Status.
    """
    LAMP_STATUS = "lamp.status"

    """
    Lamp Temperature.
    """
    LAMP_TEMPERATURE = "lamp.temperature"

    """
    Lamp Wavelength Fwhm.
    """
    LAMP_WAVELENGTH_FWHM = "lamp.wavelength.fwhm"

    """
    Lamp Wavelength Peak.
    """
    LAMP_WAVELENGTH_PEAK = "lamp.wavelength.peak"

    """
    Limit Approach Accel.
    """
    LIMIT_APPROACH_ACCEL = "limit.approach.accel"

    """
    Limit Approach Maxspeed.
    """
    LIMIT_APPROACH_MAXSPEED = "limit.approach.maxspeed"

    """
    Limit Away Action.
    """
    LIMIT_AWAY_ACTION = "limit.away.action"

    """
    Limit Away Edge.
    """
    LIMIT_AWAY_EDGE = "limit.away.edge"

    """
    Limit Away Pos.
    """
    LIMIT_AWAY_POS = "limit.away.pos"

    """
    Limit Away Posupdate.
    """
    LIMIT_AWAY_POSUPDATE = "limit.away.posupdate"

    """
    Limit Away Preset.
    """
    LIMIT_AWAY_PRESET = "limit.away.preset"

    """
    Limit Away Source.
    """
    LIMIT_AWAY_SOURCE = "limit.away.source"

    """
    Limit Away State.
    """
    LIMIT_AWAY_STATE = "limit.away.state"

    """
    Limit Away Triggered.
    """
    LIMIT_AWAY_TRIGGERED = "limit.away.triggered"

    """
    Limit Away Tune.
    """
    LIMIT_AWAY_TUNE = "limit.away.tune"

    """
    Limit Away Type.
    """
    LIMIT_AWAY_TYPE = "limit.away.type"

    """
    Limit Away Width.
    """
    LIMIT_AWAY_WIDTH = "limit.away.width"

    """
    Limit C Action.
    """
    LIMIT_C_ACTION = "limit.c.action"

    """
    Limit C Edge.
    """
    LIMIT_C_EDGE = "limit.c.edge"

    """
    Limit C Pos.
    """
    LIMIT_C_POS = "limit.c.pos"

    """
    Limit C Posupdate.
    """
    LIMIT_C_POSUPDATE = "limit.c.posupdate"

    """
    Limit C Preset.
    """
    LIMIT_C_PRESET = "limit.c.preset"

    """
    Limit C Source.
    """
    LIMIT_C_SOURCE = "limit.c.source"

    """
    Limit C State.
    """
    LIMIT_C_STATE = "limit.c.state"

    """
    Limit C Triggered.
    """
    LIMIT_C_TRIGGERED = "limit.c.triggered"

    """
    Limit C Tune.
    """
    LIMIT_C_TUNE = "limit.c.tune"

    """
    Limit C Type.
    """
    LIMIT_C_TYPE = "limit.c.type"

    """
    Limit C Width.
    """
    LIMIT_C_WIDTH = "limit.c.width"

    """
    Limit Cycle Dist.
    """
    LIMIT_CYCLE_DIST = "limit.cycle.dist"

    """
    Limit D Action.
    """
    LIMIT_D_ACTION = "limit.d.action"

    """
    Limit D Edge.
    """
    LIMIT_D_EDGE = "limit.d.edge"

    """
    Limit D Pos.
    """
    LIMIT_D_POS = "limit.d.pos"

    """
    Limit D Posupdate.
    """
    LIMIT_D_POSUPDATE = "limit.d.posupdate"

    """
    Limit D Preset.
    """
    LIMIT_D_PRESET = "limit.d.preset"

    """
    Limit D State.
    """
    LIMIT_D_STATE = "limit.d.state"

    """
    Limit D Triggered.
    """
    LIMIT_D_TRIGGERED = "limit.d.triggered"

    """
    Limit D Type.
    """
    LIMIT_D_TYPE = "limit.d.type"

    """
    Limit Detect Decelonly.
    """
    LIMIT_DETECT_DECELONLY = "limit.detect.decelonly"

    """
    Limit Detect Maxspeed.
    """
    LIMIT_DETECT_MAXSPEED = "limit.detect.maxspeed"

    """
    Limit Home Action.
    """
    LIMIT_HOME_ACTION = "limit.home.action"

    """
    Limit Home Bidirectional.
    """
    LIMIT_HOME_BIDIRECTIONAL = "limit.home.bidirectional"

    """
    Limit Home Edge.
    """
    LIMIT_HOME_EDGE = "limit.home.edge"

    """
    Limit Home Pos.
    """
    LIMIT_HOME_POS = "limit.home.pos"

    """
    Limit Home Posupdate.
    """
    LIMIT_HOME_POSUPDATE = "limit.home.posupdate"

    """
    Limit Home Preset.
    """
    LIMIT_HOME_PRESET = "limit.home.preset"

    """
    Limit Home Source.
    """
    LIMIT_HOME_SOURCE = "limit.home.source"

    """
    Limit Home State.
    """
    LIMIT_HOME_STATE = "limit.home.state"

    """
    Limit Home Triggered.
    """
    LIMIT_HOME_TRIGGERED = "limit.home.triggered"

    """
    Limit Home Tune.
    """
    LIMIT_HOME_TUNE = "limit.home.tune"

    """
    Limit Home Type.
    """
    LIMIT_HOME_TYPE = "limit.home.type"

    """
    Limit Home Width.
    """
    LIMIT_HOME_WIDTH = "limit.home.width"

    """
    Limit Max.
    """
    LIMIT_MAX = "limit.max"

    """
    Limit Min.
    """
    LIMIT_MIN = "limit.min"

    """
    Limit Range Mode.
    """
    LIMIT_RANGE_MODE = "limit.range.mode"

    """
    Limit Ref Phase.
    """
    LIMIT_REF_PHASE = "limit.ref.phase"

    """
    Limit Ref Phase Measured.
    """
    LIMIT_REF_PHASE_MEASURED = "limit.ref.phase.measured"

    """
    Limit Start Pos.
    """
    LIMIT_START_POS = "limit.start.pos"

    """
    Limit Swapinputs.
    """
    LIMIT_SWAPINPUTS = "limit.swapinputs"

    """
    Lockstep Numgroups.
    """
    LOCKSTEP_NUMGROUPS = "lockstep.numgroups"

    """
    Lockstep Tolerance.
    """
    LOCKSTEP_TOLERANCE = "lockstep.tolerance"

    """
    Maxspeed.
    """
    MAXSPEED = "maxspeed"

    """
    Motion Accel Ramptime.
    """
    MOTION_ACCEL_RAMPTIME = "motion.accel.ramptime"

    """
    Motion Accelonly.
    """
    MOTION_ACCELONLY = "motion.accelonly"

    """
    Motion Busy.
    """
    MOTION_BUSY = "motion.busy"

    """
    Motion Decelonly.
    """
    MOTION_DECELONLY = "motion.decelonly"

    """
    Motion Index Dist.
    """
    MOTION_INDEX_DIST = "motion.index.dist"

    """
    Motion Index Num.
    """
    MOTION_INDEX_NUM = "motion.index.num"

    """
    Motor Current Max.
    """
    MOTOR_CURRENT_MAX = "motor.current.max"

    """
    Motor Inductance.
    """
    MOTOR_INDUCTANCE = "motor.inductance"

    """
    Motor Phase.
    """
    MOTOR_PHASE = "motor.phase"

    """
    Motor Phase Ratio Div 1.
    """
    MOTOR_PHASE_RATIO_DIV_1 = "motor.phase.ratio.div1"

    """
    Motor Phase Ratio Div 2.
    """
    MOTOR_PHASE_RATIO_DIV_2 = "motor.phase.ratio.div2"

    """
    Motor Phase Ratio Mult.
    """
    MOTOR_PHASE_RATIO_MULT = "motor.phase.ratio.mult"

    """
    Motor Resistance.
    """
    MOTOR_RESISTANCE = "motor.resistance"

    """
    Parking State.
    """
    PARKING_STATE = "parking.state"

    """
    Peripheral Hw Modified.
    """
    PERIPHERAL_HW_MODIFIED = "peripheral.hw.modified"

    """
    Peripheral ID (Firmware 7 and higher).
    """
    PERIPHERAL_ID = "peripheral.id"

    """
    Peripheral Id Pending.
    """
    PERIPHERAL_ID_PENDING = "peripheral.id.pending"

    """
    Peripheral Serial.
    """
    PERIPHERAL_SERIAL = "peripheral.serial"

    """
    Peripheral Serial Pending.
    """
    PERIPHERAL_SERIAL_PENDING = "peripheral.serial.pending"

    """
    Peripheral ID (Firmware 6 and lower).
    """
    PERIPHERALID = "peripheralid"

    """
    Pos.
    """
    POS = "pos"

    """
    Resolution.
    """
    RESOLUTION = "resolution"

    """
    Scope Delay.
    """
    SCOPE_DELAY = "scope.delay"

    """
    Scope Timebase.
    """
    SCOPE_TIMEBASE = "scope.timebase"

    """
    Stream Numbufs.
    """
    STREAM_NUMBUFS = "stream.numbufs"

    """
    Stream Numstreams.
    """
    STREAM_NUMSTREAMS = "stream.numstreams"

    """
    System Access.
    """
    SYSTEM_ACCESS = "system.access"

    """
    System Axiscount.
    """
    SYSTEM_AXISCOUNT = "system.axiscount"

    """
    System Current.
    """
    SYSTEM_CURRENT = "system.current"

    """
    System Led Enable.
    """
    SYSTEM_LED_ENABLE = "system.led.enable"

    """
    System Serial.
    """
    SYSTEM_SERIAL = "system.serial"

    """
    System Temperature.
    """
    SYSTEM_TEMPERATURE = "system.temperature"

    """
    System Voltage.
    """
    SYSTEM_VOLTAGE = "system.voltage"

    """
    Trigger Numactions.
    """
    TRIGGER_NUMACTIONS = "trigger.numactions"

    """
    Trigger Numtriggers.
    """
    TRIGGER_NUMTRIGGERS = "trigger.numtriggers"

    """
    User Data 0.
    """
    USER_DATA_0 = "user.data.0"

    """
    User Data 1.
    """
    USER_DATA_1 = "user.data.1"

    """
    User Data 10.
    """
    USER_DATA_10 = "user.data.10"

    """
    User Data 11.
    """
    USER_DATA_11 = "user.data.11"

    """
    User Data 12.
    """
    USER_DATA_12 = "user.data.12"

    """
    User Data 13.
    """
    USER_DATA_13 = "user.data.13"

    """
    User Data 14.
    """
    USER_DATA_14 = "user.data.14"

    """
    User Data 15.
    """
    USER_DATA_15 = "user.data.15"

    """
    User Data 2.
    """
    USER_DATA_2 = "user.data.2"

    """
    User Data 3.
    """
    USER_DATA_3 = "user.data.3"

    """
    User Data 4.
    """
    USER_DATA_4 = "user.data.4"

    """
    User Data 5.
    """
    USER_DATA_5 = "user.data.5"

    """
    User Data 6.
    """
    USER_DATA_6 = "user.data.6"

    """
    User Data 7.
    """
    USER_DATA_7 = "user.data.7"

    """
    User Data 8.
    """
    USER_DATA_8 = "user.data.8"

    """
    User Data 9.
    """
    USER_DATA_9 = "user.data.9"

    """
    User Vdata 0.
    """
    USER_VDATA_0 = "user.vdata.0"

    """
    User Vdata 1.
    """
    USER_VDATA_1 = "user.vdata.1"

    """
    User Vdata 2.
    """
    USER_VDATA_2 = "user.vdata.2"

    """
    User Vdata 3.
    """
    USER_VDATA_3 = "user.vdata.3"

    """
    Vel.
    """
    VEL = "vel"

    """
    Version.
    """
    VERSION = "version"

    """
    Version Build.
    """
    VERSION_BUILD = "version.build"

    """
    Virtual Numvirtual.
    """
    VIRTUAL_NUMVIRTUAL = "virtual.numvirtual"



# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class ServoTuningParamset(Enum):
    """
    Servo Tuning Parameter Set to target.
    """

    LIVE = 0
    P_1 = 1
    P_2 = 2
    P_3 = 3
    P_4 = 4
    P_5 = 5
    P_6 = 6
    P_7 = 7
    P_8 = 8
    P_9 = 9
    STAGING = 10
    DEFAULT = 11
